use std::sync::Arc;

use axum::{
    http::StatusCode,
    response::{IntoResponse, Response},
    Extension, Json,
};
use ubisync_lib::{api::events::{PollEventsRequest, PollEventsResponse}, types::AppId};

use crate::state::ApiState;


pub(super) async fn poll(
    app: Extension<AppId>,
    s: Extension<Arc<ApiState>>,
    Json(req): Json<PollEventsRequest>,
) -> Response {
    match s.events(app.0, req.timeout, req.accumulate).await {
        Ok(events) => (
            StatusCode::OK,
            Json {
                0: PollEventsResponse { events },
            },
        )
            .into_response(),
        Err(_) => (
            StatusCode::CONFLICT,
            "Another poll request is currently being handled",
        )
            .into_response(),
    }
}
